import { DEFAULT_NETWORK, networkPlatformConfigs, getProtocolInitializer, } from '@wormhole-foundation/connect-sdk';
import { ethers } from 'ethers';
import { EvmChain } from './chain';
import { EvmUtils } from './platformUtils';
// forces EvmPlatform to implement Platform
var _ = EvmPlatform;
/**
 * @category EVM
 */
// Provides runtime concrete value
export var EvmPlatform;
(function (EvmPlatform) {
    EvmPlatform.platform = 'Evm';
    EvmPlatform.network = DEFAULT_NETWORK;
    EvmPlatform.conf = networkPlatformConfigs(EvmPlatform.network, EvmPlatform.platform);
    EvmPlatform.nativeTokenId = EvmUtils.nativeTokenId, EvmPlatform.isNativeTokenId = EvmUtils.isNativeTokenId, EvmPlatform.isSupportedChain = EvmUtils.isSupportedChain, EvmPlatform.getDecimals = EvmUtils.getDecimals, EvmPlatform.getBalance = EvmUtils.getBalance, EvmPlatform.getBalances = EvmUtils.getBalances, EvmPlatform.sendWait = EvmUtils.sendWait, EvmPlatform.getCurrentBlock = EvmUtils.getCurrentBlock, EvmPlatform.chainFromChainId = EvmUtils.chainFromChainId, EvmPlatform.chainFromRpc = EvmUtils.chainFromRpc, EvmPlatform.getTokenImplementation = EvmUtils.getTokenImplementation;
    function setConfig(_network, _conf) {
        EvmPlatform.conf = _conf ? _conf : networkPlatformConfigs(EvmPlatform.network, EvmPlatform.platform);
        EvmPlatform.network = _network;
        return EvmPlatform;
    }
    EvmPlatform.setConfig = setConfig;
    function getRpc(chain) {
        if (chain in EvmPlatform.conf)
            return ethers.getDefaultProvider(EvmPlatform.conf[chain].rpc);
        throw new Error('No configuration available for chain: ' + chain);
    }
    EvmPlatform.getRpc = getRpc;
    function getChain(chain) {
        if (chain in EvmPlatform.conf)
            return new EvmChain(EvmPlatform.conf[chain]);
        throw new Error('No configuration available for chain: ' + chain);
    }
    EvmPlatform.getChain = getChain;
    function getProtocol(protocol) {
        return getProtocolInitializer(EvmPlatform.platform, protocol);
    }
    EvmPlatform.getProtocol = getProtocol;
    async function getWormholeCore(rpc) {
        return getProtocol('WormholeCore').fromRpc(rpc, EvmPlatform.conf);
    }
    EvmPlatform.getWormholeCore = getWormholeCore;
    async function getTokenBridge(rpc) {
        return getProtocol('TokenBridge').fromRpc(rpc, EvmPlatform.conf);
    }
    EvmPlatform.getTokenBridge = getTokenBridge;
    async function getAutomaticTokenBridge(rpc) {
        return getProtocol('TokenBridge').fromRpc(rpc, EvmPlatform.conf);
    }
    EvmPlatform.getAutomaticTokenBridge = getAutomaticTokenBridge;
    async function getCircleBridge(rpc) {
        return getProtocol('CircleBridge').fromRpc(rpc, EvmPlatform.conf);
    }
    EvmPlatform.getCircleBridge = getCircleBridge;
    async function getAutomaticCircleBridge(rpc) {
        return getProtocol('AutomaticCircleBridge').fromRpc(rpc, EvmPlatform.conf);
    }
    EvmPlatform.getAutomaticCircleBridge = getAutomaticCircleBridge;
    async function parseTransaction(chain, rpc, txid) {
        const wc = await getWormholeCore(rpc);
        return wc.parseTransaction(txid);
    }
    EvmPlatform.parseTransaction = parseTransaction;
})(EvmPlatform || (EvmPlatform = {}));
//# sourceMappingURL=platform.js.map